@@ -13,4 +13,4 @@ def main(files, **kwargs):
 
 
 if __name__ == "__main__":
-    main()  # pylint: disable=no-value-for-parameter
+    main()
