@@ -99,6 +99,8 @@ class GetHash(object):
 
         self.glob_mode = kwargs.pop("glob", 1)
         self.glob_type = kwargs.pop("type", "a")
+        self.recursive = kwargs.pop("recursive", False)
+        self.sync = kwargs.pop("sync", False)
 
         self.stdout = kwargs.pop("stdout", sys.stdout)
         self.stderr = kwargs.pop("stderr", sys.stderr)
@@ -139,7 +141,12 @@ class GetHash(object):
         click.secho(msg, file=self.stderr, fg="red")
 
     def glob_function(self, pathnames):
-        return glob_filters(pathnames, mode=self.glob_mode, type=self.glob_type)
+        return glob_filters(
+            pathnames,
+            mode=self.glob_mode,
+            type=self.glob_type,
+            recursive=self.recursive,
+        )
 
     def hash_function(self, path):
         return self.hasher(path, self.start, self.stop, dir_ok=self.dir_ok)
@@ -158,6 +165,10 @@ class GetHash(object):
                 hash_line = generate_hash_line(path, self.hash_function, root=root)
                 hash_path = path + self.suffix
                 self.output.dump(hash_line, hash_path)
+
+                if self.sync:
+                    t = os.path.getmtime(path)
+                    os.utime(hash_path, (t, t))
             except Exception as e:
                 self.echo_error(path, e)
             else:
@@ -169,6 +180,10 @@ class GetHash(object):
             try:
                 root = self.check_root(hash_path)
                 path = check_hash_line(hash_line, self.hash_function, root=root)
+
+                if self.sync:
+                    t = os.path.getmtime(path)
+                    os.utime(hash_path, (t, t))
             except CheckHashLineError as e:
                 self.echo(f"[FAILURE] {e.path}", fg="red")
             except Exception as e:
@@ -218,7 +233,7 @@ def gethashcli(cmdname, hashname, suffix):
             "Output Mode", help="Set the file output mode."
         )
 
-        @click.command(
+        @click.command(  # type: ignore [call-arg]
             cmdname,
             context_settings=dict(help_option_names=["-h", "--help"]),
             no_args_is_help=True,
@@ -230,8 +245,6 @@ def gethashcli(cmdname, hashname, suffix):
             is_flag=True,
             help=f"Read {hashname} from FILES and check them.",
         )
-        @click.option("--start", type=click.INT, help="The start offset of files.")
-        @click.option("--stop", type=click.INT, help="The stop offset of files.")
         @click.option(
             "-d",
             "--dir",
@@ -239,6 +252,13 @@ def gethashcli(cmdname, hashname, suffix):
             help="Allow checksum for directories. "
             "Just xor each checksum of files in a given directory.",
         )
+        @click.option(
+            "--suffix",
+            metavar="SUFFIX",
+            default=suffix,
+            show_default=True,
+            help="Set the filename extension of checksum files.",
+        )
         @click.option(
             "-g",
             "--glob",
@@ -259,11 +279,18 @@ def gethashcli(cmdname, hashname, suffix):
             "directories; if ``f``, include files.",
         )
         @click.option(
-            "--suffix",
-            metavar="SUFFIX",
-            default=suffix,
-            show_default=True,
-            help="Set the filename extension of checksum files.",
+            "-r",
+            "--recursive",
+            is_flag=True,
+            help="Enable recursive matching, i.e. "
+            "the pattern ``**`` will match any files and zero or more "
+            "directories, subdirectories and symbolic links to directories.",
+        )
+        @click.option(
+            "-y",
+            "--sync",
+            is_flag=True,
+            help="Update mtime of hash files to the same as data files.",
         )
         @path_format.option(
             "-i", "--inplace", is_flag=True, help="Use basename in checksum files."
@@ -295,6 +322,8 @@ def gethashcli(cmdname, hashname, suffix):
             is_flag=True,
             help="Do not output to files. This is the default output mode.",
         )
+        @click.option("--start", type=click.INT, help="The start offset of files.")
+        @click.option("--stop", type=click.INT, help="The stop offset of files.")
         @click.option("--tqdm-ascii", type=click.BOOL, default=False, show_default=True)
         @click.option(
             "--tqdm-disable", type=click.BOOL, default=False, show_default=True
